@@ -121,4 +121,19 @@ class RDSClient():
         """
         """
         query = f"UPDATE neuralplatform_version v SET status = '{status}' WHERE v.id = {version_id};"
-        return self.update_query(query)
+        return self.update_query(query)        
+
+    def get_document_name_and_uri(self,
+                    document_id: int) -> tuple:
+        """
+        """
+        query = f"SELECT name, uri FROM neuralplatform_document WHERE id = {document_id};"
+        return self.select_query(query)
+            
+    def insert_page(self,
+                    img_uri: str,
+                    document_id: int) -> int:
+        """
+        """
+        query = f'INSERT INTO neuralplatform_page(imgUri, ocrUri, document_id) VALUES ("{img_uri}", "", {document_id});'
+        return self.insert_query(query)
